# This spec file is derived from the RHEL9 fence-agents spec file.
# https://gitlab.com/redhat/centos-stream/rpms/fence-agents
%global _debugsource_template %{nil}

Name: fence-agents-epel
Summary: Set of unified programs capable of host isolation ("fencing")
Version: 4.10.0
Release: 30%{?dist}
License: GPLv2+ and LGPLv2+
URL: https://github.com/ClusterLabs/fence-agents
Source0: https://fedorahosted.org/releases/f/e/fence-agents/fence-agents-%{version}.tar.gz
BuildArch: noarch

# Build dependencies
## man pages generating
BuildRequires: libxslt
## Python dependencies
%if 0%{?fedora} || 0%{?centos} > 7 || 0%{?rhel} > 7 || 0%{?suse_version}
BuildRequires: python3-devel python3-pip
BuildRequires: python3-wheel
BuildRequires: python3-pycurl python3-requests
%endif

%prep
%setup -q -n fence-agents-%{version}

%build
%if 0%{?fedora} || 0%{?centos} > 7 || 0%{?rhel} > 7 || 0%{?suse_version}
	export PYTHON="%{__python3}"
%endif

%install
rm -rf %{buildroot}

mkdir -p %{buildroot}/%{_sbindir}
install -m 0755 %{_builddir}/fence-agents-%{version}/agents/pve/fence_pve.py %{buildroot}%{_sbindir}/fence_pve
install -m 0755 %{_builddir}/fence-agents-%{version}/agents/raritan/fence_raritan.py  %{buildroot}%{_sbindir}/fence_raritan
install -m 0755 %{_builddir}/fence-agents-%{version}/agents/rcd_serial/fence_rcd_serial.py  %{buildroot}%{_sbindir}/fence_rcd_serial
install -m 0755 %{_builddir}/fence-agents-%{version}/agents/virsh/fence_virsh.py  %{buildroot}%{_sbindir}/fence_virsh
sed -i "s|@PYTHON@ -tt|%{__python3}|" %{buildroot}%{_sbindir}/fence*

# bytecompile Python source code in a non-standard location
%if 0%{?fedora} || 0%{?centos} > 7 || 0%{?rhel} > 7
%py_byte_compile %{__python3} %{buildroot}%{_sbindir}/fence*
%endif

## tree fix up
# fix libfence permissions
chmod 0755 %{buildroot}%{_sbindir}/fence_{pve,raritan,rcd_serial,virsh}
# remove docs
rm -rf %{buildroot}/usr/share/doc/fence-agents
# remove .a files
rm -f %{buildroot}/%{_libdir}/fence-agents/*.*a



%description
A collection of executables to handle isolation ("fencing") of possibly
misbehaving hosts by the means of remote power management, blocking
network, storage, or similar. They operate through a unified interface
(calling conventions) devised for the original Red Hat clustering solution.

%package -n fence-agents-pve
License: GPLv2+ and LGPLv2+
Summary: Fence agent for PVE
Requires: python3-pycurl
Requires: fence-agents-common = %{version}
BuildArch: noarch
%description -n fence-agents-pve
Fence agent for PVE.
%files -n fence-agents-pve
%{_sbindir}/fence_pve
#%{_mandir}/man8/fence_pve.8*

%package -n fence-agents-raritan
License: GPLv2+ and LGPLv2+
Summary: Fence agent for Raritan Dominion PX
Requires: fence-agents-common = %{version}
BuildArch: noarch
%description -n fence-agents-raritan
Fence agent for Raritan Dominion PX.
%files -n fence-agents-raritan
%{_sbindir}/fence_raritan
#%{_mandir}/man8/fence_raritan.8*

%package -n fence-agents-rcd-serial
License: GPLv2+ and LGPLv2+
Summary: Fence agent for RCD serial
Requires: fence-agents-common = %{version}
BuildArch: noarch
%description -n fence-agents-rcd-serial
Fence agent for RCD serial.
%files -n fence-agents-rcd-serial
%{_sbindir}/fence_rcd_serial
#%{_mandir}/man8/fence_rcd_serial.8*

%package -n fence-agents-virsh
License: GPLv2+ and LGPLv2+
Summary: Fence agent for virtual machines based on libvirt
Requires: openssh-clients /usr/bin/virsh
Requires: fence-agents-common = %{version}
BuildArch: noarch
%description -n fence-agents-virsh
Fence agent for virtual machines that are accessed via SSH.
%files -n fence-agents-virsh
%{_sbindir}/fence_virsh
#%{_mandir}/man8/fence_virsh.8*


%changelog
* Fri Aug 26 2022 Troy Dawson <tdawson@redhat.com> - 4.10.0-30
- Convert RHEL9 fence-agents to  fence-agents-epel.  It only provides
  fence-agents pve, raritan, rcd-serial, and virsh.
- Related: rhbz#2029251

* Tue Aug 16 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-30
- fence_openstack: add support for reading config from clouds.yaml
  and openrc
  Resolves: rhbz#2041933, rhbz#2041935

* Wed Jun 22 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-27
- fence_ibm_powervs: add support for proxy, private API servers and
  get token via API key
  Resolves: rhbz#2093216

* Wed Jun  1 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-26
- fence_ibm_vpc: add proxy support
  Resolves: rhbz#2092385

* Tue May 31 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-25
- all agents: unify ssl parameters to avoid having to use --ssl when
  using --ssl-secure/--ssl-insecure for some agents
  Resolves: rhbz#2072420

* Tue May 17 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-24
- fence_apc/fence_ilo_moonshot: add missing "import logging"
  Resolves: rhbz#2086559

* Thu May  5 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-23
- fence_ibm_vpc: remove unused instance parameter and make limit
  optional
  Resolves: rhbz#2081235

* Fri Apr 29 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-22
- fence_gce: update fence agent
  Resolves: rhbz#2079889

* Wed Apr  6 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-21
- fence_lpar: refactor to avoid duplicate code
  Resolves: rhbz#2065114

* Wed Mar 30 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-20
- fence_azure_arm: fix sovereign cloud and MSI support
  Resolves: rhbz#2010652

* Mon Mar  7 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-19
- fence_ibm_vpc: new fence agent
  Resolves: rhbz#2061321

* Fri Feb 11 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-18
- fence_zvmip: add SSL/TLS support
  Resolves: rhbz#2022334

* Mon Feb  7 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-17
- fence_ibm_powervs: new fence agent
  Resolves: rhbz#2042496

* Mon Jan 17 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-15
- fence_kubevirt: new fence agent
  Resolves: rhbz#2000954

* Tue Jan 11 2022 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-14
- fence_openstack: add --ssl-insecure
  Resolves: rhbz#2029791

* Thu Dec  2 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-13
- fence_amt_ws: fix "or" causing dead code
  Resolves: rhbz#2010709

* Tue Aug 31 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-9
- Only build fence-virt subpackages for x86_64 arch
  Resolves: rhbz#1965988

* Tue Aug 31 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-8
- OpenStack agents: add dependency
  Resolves: rhbz#1857247

* Wed Aug 25 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-7
- remove suds dependency
  Resolves: rhbz#1989149

* Mon Aug 09 2021 Mohan Boddu <mboddu@redhat.com> - 4.10.0-4
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Mon Jul 26 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.10.0-2
- new upstream release
  Resolves: rhbz#1984803

* Wed Jul  7 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.9.0-5
- Remove "BuildArch: noarch" for arch-specific subpackages
  Resolves: rhbz#1979827

* Fri Jun  4 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.9.0-1
- Rebase and add fence-virt subpackages
  Resolves: rhbz#1965988

* Tue May 18 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.1-10
- remove pexpect dependency
  Resolves: rhbz#1961551

* Thu Apr 15 2021 Mohan Boddu <mboddu@redhat.com> - 4.7.1-9
- Rebuilt for RHEL 9 BETA on Apr 15th 2021. Related: rhbz#1947937

* Tue Mar 23 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.1-8
- cloud agents: only build for x86_64

* Thu Mar  4 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.1-5
- update HA cloud support package

* Mon Feb 15 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.1-4
- create HA cloud support package

* Thu Feb 11 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.1-3
- add aliyun subpackage
- fence-agents-mpath: add missing fence_mpath_check*

* Mon Feb  8 2021 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.1-1
- new upstream release

* Wed Dec  9 2020 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.7.0-1
- new upstream release

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.5.2-4
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.5.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 4.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Oct 23 2019 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.5.2-1
- new upstream release
- added openstack subpackage
- spec improvements based on upstream spec-file

* Tue Sep 24 2019 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.5.1-1
- new upstream release

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Jun  4 2019 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.4.0-1
- new upstream release

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.3.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Jan 16 2019 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.3.3-2
- fence-agents-scsi: add missing fence-agents-common dependency

* Mon Dec  3 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.3.3-1
- new upstream release

* Fri Oct  5 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.3.0-1
- new upstream release

* Wed Sep 19 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.2.1-6
- Fix missing fence-agents-all subpackage after spec improvements

* Wed Aug 22 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.2.1-5
- Python 3: fix has_key() issues

* Mon Aug 20 2018 Jan Pokorný <jpokorny+rpm-booth@fedoraproject.org> - 4.2.1-4
- mark non-compiled packages properly as noarch, restructure excludes
- move azure_fence.py and XenAPI.py to respective subpackages from -common
- sanitize allfenceagents internally defined enumeration
- sanitize BuildRequires with respect to packaging guidelines
- bytecompile native Python modules and ship these bytecodes properly
- only refer to Python binary symbolically, drop buildroot cleanup
- cleanup package summaries/descriptions, order agent subpackages properly

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Jun 18 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.2.1-2
- fence_vmware_soap: fix python3-suds issue

* Thu May 31 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.2.1-1
- new upstream release

* Fri May 25 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.2.0-2
- fence_scsi: fix Python 3 encoding issue

* Thu May 17 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.2.0-1
- new upstream release

* Thu Feb 15 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.1.1-1
- new upstream release
- fence_vmware_soap / fence_ovh: use Python 2 till python3-suds bug
  is fixed

* Fri Feb  9 2018 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.1.0-2
- new upstream release

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.24-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 11 2018 Iryna Shcherbina <ishcherb@redhat.com> - 4.0.24-14
- Cleanup no longer needed Python 2 dependencies

* Tue Nov 07 2017 Troy Dawson <tdawson@redhat.com> - 4.0.24-13
- Cleanup spec file conditionals

* Tue Aug 29 2017 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.24-12
- fence-agents-common: remove fence_scsi_check files
- fence-scsi: add "fence_scsi_check_hardreboot"

* Thu Aug  3 2017 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.24-10
- fence_zvm: fix "uintptr_t" undeclared

* Thu Aug  3 2017 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.24-9
- Fix encoding for pexpect with Python 3.6
  Resolves: rhbz#1473908

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.24-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.24-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.24-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Dec 23 2016 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.24-5
- Fix to build in Python 3 only environment

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 4.0.24-4
- Rebuild for Python 3.6

* Wed Sep 21 2016 Marek Grac <mgrac@redhat.com> - 4.0.24-4
- Remove Obsoletes that are no longer valid

* Fri Sep  2 2016 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.24-2
- fence-agents-common: add dependency on python3-pycurl

* Fri Aug 26 2016 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.24-1
- new upstream release

* Wed Jul 13 2016 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.23-2
- fix build issue on s390

* Tue Jul 12 2016 Oyvind Albrigtsen <oalbrigt@redhat.com> - 4.0.23-1
- new upstream release
- new package fence-agents-amt-ws
- new package fence-agents-compute
- new package fence-agents-drac
- new package fence-agents-hds-cb
- new package fence-agents-mpath
- new package fence-agents-sanbox2
- new package fence-agents-sbd
- new package fence-agents-vbox
- new package fence-agents-vmware
- new package fence-agents-xenapi

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.20-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Aug 11 2015 Marek Grac <mgrac@redhat.com> - 4.0.20-1
- new upstream release
- new package fence-agents-rcd-serial

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Mar 05 2015 Marek Grac <mgrac@redhat.com> - 4.0.16-1
- new upstream release

* Mon Feb 09 2015 Marek Grac <mgrac@redhat.com> - 4.0.15-1
- new upstream release

* Thu Jan 08 2015 Marek Grac <mgrac@redhat.com> - 4.0.14-1
- new upstream release
- new packages fence-agents-zvm and fence-agents-emerson

* Thu Oct 16 2014 Marek Grac <mgrac@redhat.com> - 4.0.12-1
- new upstream release
- new package fence-agents-ilo-ssh

* Wed Aug 27 2014 Marek Grac <mgrac@redhat.com> - 4.0.10
- new upstream release
- new package fence-agents-ilo-moonshot

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 16 2014 Marek Grac <mgrac@redhat.com> - 4.0.9
- new upstream release
- new package fence-agents-pve

* Mon Apr 07 2014 Marek Grac <mgrac@redhat.com> - 4.0.8-1
- new upstream release
- new package fence-agents-raritan

* Wed Feb 26 2014 Marek Grac <mgrac@redhat.com> - 4.0.7-3
- requires a specific version of fence-agents-common

* Mon Feb 17 2014 Marek Grac <mgrac@redhat.com> - 4.0.7-2
- new upstream release
- changed dependancy from nss/nspr to gnutls-utils

* Fri Jan 10 2014 Marek Grac <mgrac@redhat.com> - 4.0.4-4
- new upstream release
- new package fence-agents-amt

* Mon Oct 07 2013 Marek Grac <mgrac@redhat.com> - 4.0.4-3
- new upstream release
- new package fence-agents-netio

* Tue Sep 03 2013 Marek Grac <mgrac@redhat.com> - 4.0.3-1
- new upstream release
- new packages fence-agents-brocade and fence-agents-ovh

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Jul 18 2013 Petr Pisar <ppisar@redhat.com> - 4.0.1-2
- Perl 5.18 rebuild

* Mon Jul 01 2013 Marek Grac <mgrac@redhat.com> - 4.0.1-1
- new upstream release

* Mon Jun 24 2013 Marek Grac <mgrac@redhat.com> - 4.0.0-5
- fence-agents-all should provide fence-agent for clean update path

* Wed Apr 03 2013 Marek Grac <mgrac@redhat.com> - 4.0.0-4
- minor changes in spec file

* Thu Mar 21 2013 Marek Grac <mgrac@redhat.com> - 4.0.0-3
- minor changes in spec file

* Mon Mar 18 2013 Marek Grac <mgrac@redhat.com> - 4.0.0-2
- minor changes in spec file

* Mon Mar 11 2013 Marek Grac <mgrac@redhat.com> - 4.0.0-1
- new upstream release
- introducing subpackages


